#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-gdkx11
version:                3.0.16
visibility:             public
id:                     gi-gdkx11-3.0.16-IYT81ZCKqXJ1JG997wEKr0
key:                    gi-gdkx11-3.0.16-IYT81ZCKqXJ1JG997wEKr0
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               GdkX11 bindings
description:            Bindings for GdkX11, autogenerated by haskell-gi.
category:               Bindings
abi:                    3fb0b2d78a35d9e52dc59d669bcd6979
exposed:                True
exposed-modules:
    GI.GdkX11 GI.GdkX11.Config GI.GdkX11.Functions GI.GdkX11.Objects
    GI.GdkX11.Objects.X11AppLaunchContext GI.GdkX11.Objects.X11Cursor
    GI.GdkX11.Objects.X11DeviceCore
    GI.GdkX11.Objects.X11DeviceManagerCore
    GI.GdkX11.Objects.X11DeviceManagerXI2
    GI.GdkX11.Objects.X11DeviceXI2 GI.GdkX11.Objects.X11Display
    GI.GdkX11.Objects.X11DisplayManager
    GI.GdkX11.Objects.X11DragContext GI.GdkX11.Objects.X11GLContext
    GI.GdkX11.Objects.X11Keymap GI.GdkX11.Objects.X11Monitor
    GI.GdkX11.Objects.X11Screen GI.GdkX11.Objects.X11Visual
    GI.GdkX11.Objects.X11Window

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-gdkx11-3.0.16
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-gdkx11-3.0.16 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-gdkx11-3.0.16 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-gdk3x11
hs-libraries:           HSgi-gdkx11-3.0.16-IYT81ZCKqXJ1JG997wEKr0
extra-libraries:
    gdk-3 pangocairo-1.0 pango-1.0 harfbuzz gdk_pixbuf-2.0
    cairo-gobject cairo gobject-2.0 glib-2.0 z

extra-libraries-static:
    gdk-3 pangocairo-1.0 m pangoft2-1.0 m pango-1.0 m thai datrie Xft
    harfbuzz-gobject harfbuzz m graphite2 gdk_pixbuf-2.0 m glycin-2
    seccomp lcms2 m pthread cairo-gobject dl Xi Xrandr Xcursor
    Xcomposite Xdamage Xfixes Xinerama xkbcommon wayland-cursor
    wayland-egl wayland-client m rt cairo m dl fontconfig m expat m
    freetype dl bz2 png16 m m brotlidec brotlicommon Xext Xrender
    xcb-render xcb-shm pixman-1 m epoxy dl X11 pthread xcb Xau Xdmcp GL
    EGL cloudproviders gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    atomic m pcre2-8 pthread z mount blkid systemd sysprof-capture-4
    fribidi

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/harfbuzz /usr/include/gdk-pixbuf-2.0
    /usr/include/glycin-2 /usr/include/cairo /usr/include/freetype2
    /usr/include/libpng16 /usr/include/pixman-1
    /usr/include/cloudproviders /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6
    /usr/include/fribidi

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-cairo-1.0.30-4lO5r9X1FCKFg7uBNimvKQ
    gi-gdk-3.0.29-4wlkl6Icf0447zQrmaYpk0
    gi-gio-2.0.38-KhfQKptKtz24DoUmsqhUmu
    gi-gobject-2.0.31-JxZaUbUOnahGAnv5khBK1k
    gi-xlib-2.0.14-GzulfIa42ooGUY0QjykSnq
    haskell-gi-0.26.17-JoTSFqJqjJ4EGDfWawwGSB
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-gdk3x11/html/gi-gdkx11.haddock
haddock-html:           /usr/share/doc/haskell-gi-gdk3x11/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

